/**
 * 模型列表
 * tableName 字段 = 数据表名称【必有值】 使用TABLEENUM的枚举值
 * source 字段 = 数据源【必有值】 可选为mongo 或者 mysql  使用枚举值
 * schema字段说明
 *   allowNull    |   是否为空   |   true=可以为空
 *   type         |   类型       |   String, Number, [String], [Number]
 *   primaryKey   |   表示主键   |   true = 是主键
 *   autoIncrement|   自增       |   是否允许自增  true = 允许
 *   unique       |   值唯一     |   表示值是否唯一
 *   default      |   默认值     |   表示默认时间
 *   index        |   索引       |   true = 建立索引
 * 
 * type类型说明
 * Mongo可用 String,[String],Number,[Number],Boolean
 * sql可用   String,Number,Boolean,Date
 * 
 * association字段说明  多表关联  【数组型】【mysql用】
 * 例：A表有主键aId  B表有外键aId  如需要关联 应在 A的模型下加入association配置
 *  {type: "hasMany", check: "外键表名", foreignKey:"关联字段"},
 * 
 * 子文档字段说明    子文档     【数组型】【mongo用】
 * 例：A表下有sub字段，该字段是子文档B，如需要做关联
 * ·先在模型列表中定义B模型 
 * ·然后A模型中的sub字段定义为[B]或B    {name:"String", sub:'[B]'} 
 * 
 * 注意事项：
 * 1.不通数据源的表名不可重复，也就是说即使在mysql和mongo同时存在的情况下，表名都不可以重复
 * 
 * 
 * {
        tableName:TABLEENUM.表名1,//数据库名称
        source:TABLESOURCEENUM.mongo,
        schema:{
            bId:{
                type:'Number',
            },
            name:'String',
            subFile:'table2'
        }
    },
    {
        tableName:TABLEENUM.表名2,//数据库名称
        source:TABLESOURCEENUM.mysql,
        schema:{
            aId:{
                type:'Number',
            },
            sex:'String',
            count:{type:'Number', default:1}
        },
        association:[]
    },
 */

import { MEMBERSTATE, REGISTERFLOW, USERREGISTERSTATE } from "../../config/enum";



enum TABLESOURCEENUM {
    mysql = 1,
    mongo = 2
}

enum TABLEENUM {
    学会概括 = 'xueHuiGaiKuo',
    学会领导 = 'xueHuiLingDao',
    学会架构 = 'xueHuiJiaGou',
    图片编辑 = 'tuPianBianJi',
    芳华杯 = 'fangHuaBei',
    党建 = 'dangJian',
    下载专区 = 'xiaZaiZhuanQu',
    会议通知 = 'huiYiTongZhi',
    文章管理 = 'wenZhangGuanLi',
    banner管理 = 'bannerGuanLi',
    视频管理 = 'shiPinGuanLi',
    专题系列 = 'zhuanTiXiLie',
    机构管理 = 'jiGouGuanLi',
    活动通知 = 'huoDongTongZhi',
    项目公告 = 'xiangMuGongGao',
    工作动态 = 'gongZuoDongTai',
    委员名单 = 'weiYuanMingDan',
    用户表 = 'users',
    文字资料 = 'wenZiZiLiao',
    订单表 = 'order',
    单位所获得科研成果表 = "scientificResearch",
    验证码表 = "code",
}

const ModelArray = [
    {
        tableName:TABLEENUM.学会概括,
        source:TABLESOURCEENUM.mongo,
        schema:{
            id:{ type:'String', index:true },
            title:{ type:'String', default:'' },//标题
            desc:{ type:'String', default:'' },//简介
            imgList:{ type:'[String]', default:[] },//图片地址
            ut:{ type:'Number'}//最后一次修改时间
        }
    },
    {
        tableName:TABLEENUM.学会领导,
        source:TABLESOURCEENUM.mongo,
        schema:{
            id:{ type:'String', index:true },
            rank:{ type:'Number' },//排序
            name:{ type:'String', default:'' },//名称
            position:{ type:'String', default:'' },//职位
            imgUrl:{ type:'String', default:''},//大图地址
            miniImgUrl:{ type:'String', default:'' },//小图片地址
            desc:{ type:'String', default:'' },//描述
            ct:{ type:'Number'}//创建 时间
        }
    },
    {
        tableName:TABLEENUM.学会架构,
        source:TABLESOURCEENUM.mongo,
        schema:{
            id:{ type:'String', index:true },
            departmentName:{ type:'String', default:'' },//部门名称
            desc:{ type:'String', default:'' },//部门介绍
            display:{ type:'Number', default:0},//是否显示
            ct:{ type:'Number'}//创建 时间
        }
    },
    {
        tableName:TABLEENUM.图片编辑,
        source:TABLESOURCEENUM.mongo,
        schema:{
            id:{ type:'String', index:true },
            type:'Number',//枚举 IMGEDITFUNENUM
            index:'Number',
            imgUrl:{type:'String', default:''},
            desc:{type:'String', default:''}
        }
    },
    {
        tableName:TABLEENUM.芳华杯,
        source:TABLESOURCEENUM.mongo,
        schema:{
            id:{ type:'String', index:true },
            name:'String',
            works:'String',
            worksType:'Number',//作品类型枚举
            awardTime:'Number',//获奖时间
            desc:{type:'String', default:''}
        }
    },
    {
        tableName:TABLEENUM.党建,//党建类型
        source:TABLESOURCEENUM.mongo,
        schema:{
            id:{ type:'Number', index:true },
            type:'Number',//选项中的二级名称 枚举 PARTYBUILDTYPEENUM
            subType:'Number',//区分学习园地的视频资源和文章资源
            display:'Number',//是否在官网显示
            name:'String'
        }
    },
    {
        tableName:TABLEENUM.文字资料,
        source:TABLESOURCEENUM.mongo,
        schema:{
            id:{ type:'String', index:true },
            title:'String',//展示标题
            rank:'Number',//排序
            imgUrl:'String',//图片地址
            position:'Number',//位置
            articleTitle:'String',//文章标题
            articleUrl:'String',//链接 前端生成
            type:'Number',//分类 参考党建表>学习园地>文字资料
            updateTime:'Number',//更新时间
        }
    },
    {
        tableName:TABLEENUM.文章管理,
        source:TABLESOURCEENUM.mongo,
        schema:{
            id:{ type:'String', index:true },
            title:'String',//文章大标题
            articleType:'[Number]',//文章类型
            imgUrl:'[String]',//图片地址
            articleTime:'Number',//文章时间
            desc:'String',//内容
            display:{type:'Number', default:0},//是否显示 使用是否的枚举
            ct:'Number'
        }
    },
    {
        tableName:TABLEENUM.banner管理,
        source:TABLESOURCEENUM.mongo,
        schema:{
            id:{ type:'String', index:true },
            location:'Number',//所属位置枚举 24.3.1改成单选
            position:'Number',//位置
            articleTitle:'String',//文章标题
            imgUrl:'String',//图片地址
            articleUrl:'String',//文章链接
            desc:'String',//副标题
            display:{type:'Number', default:0},//是否显示 使用是否的枚举
            ct:'Number'
        }
    },
    {
        tableName:TABLEENUM.视频管理,
        source:TABLESOURCEENUM.mongo,
        schema:{
            id:{ type:'String', index:true },
            title:'String',//大标题
            videoType:'Number',//分类
            videoUrl:'String',//视频地址
            videoTime:'Number',//video时间
            desc:'String',//说明
            display:{type:'Number', default:0},//是否显示 使用是否的枚举
            ct:'Number',
            coverUrl:'String',//封面图片
        }
    },
    {
        tableName:TABLEENUM.专题系列,
        source:TABLESOURCEENUM.mongo,
        schema:{
            id:{ type:'String', index:true },
            rank:'Number',//排序 不可被修改
            title:'String',//标题
            position:'Number',//位置
            articleTitle:'String',//文章标题
            articleUrl:'String',//链接 前端生成
            imgUrl:'String',
            ct:'Number'
        }
    },
    {
        tableName:TABLEENUM.机构管理,
        source:TABLESOURCEENUM.mongo,
        schema:{
            id:{ type:'String', index:true },
            name:'String',//机构名称
            desc:'String',//内容
            createTime:'Number',//成立时间
            rank:'Number',
            logoUrl:'String',
            ct:'Number',
        }
    },
    {
        tableName:TABLEENUM.会议通知,
        source:TABLESOURCEENUM.mongo,
        schema:{
            id:{ type:'String', index:true },
            name:'String',//会议名称
            st:'Number',
            addrest:'String',
            members:{type:'[Number]', default:[]},//参会会员id，用中文逗号隔开
            push:'Number',//是否开启推送
            desc:'String',//参会说明
            ct:'Number'
        }
    },
    {
        tableName:TABLEENUM.活动通知,
        source:TABLESOURCEENUM.mongo,
        schema:{
            id:{ type:'String', index:true },
            name:'String',//活动名称
            st:'Number',//开始时间
            addrest:'String',
            members:{type:'[Number]', default:[]},//参会会员id，用中文逗号隔开
            push:'Number',//是否开启推送
            desc:'String',//参会说明
            ct:'Number'
        }
    },
    {
        tableName:TABLEENUM.项目公告,
        source:TABLESOURCEENUM.mongo,
        schema:{
            id:{ type:'String', index:true },
            name:'String',//项目名称
            st:'Number',
            addrest:'String',
            members:{type:'[Number]', default:[]},//参会会员id，用中文逗号隔开
            push:'Number',//是否开启推送
            desc:'String',//项目说明
            ct:'Number'
        }
    },
    {
        tableName:TABLEENUM.工作动态,
        source:TABLESOURCEENUM.mongo,
        schema:{
            id:{type:'String', index:true },
            agencyId:{type:'String', index:true},//机构id
            title:'String',//标题
            activityTime:'Number',//创建时间
            imgUrl:'String',//图片地址
            desc:'String',//内容
            isUse:{type:'Number', default:0},//是否上架0表示不上架1表示上架
            ct:'Number'
        }
    },
    {
        tableName:TABLEENUM.委员名单,
        source:TABLESOURCEENUM.mongo,
        schema:{
            id:{type:'String', index:true },
            agencyId:{type:'String', index:true},//机构id
            name:'String',//姓名
            branchDuties:'Number',//分会职务
            unit:'String',//单位
            unitDuties:'String',//单位职务
            ct:'Number'
        }
    },
    {
        tableName:TABLEENUM.下载专区,
        source:TABLESOURCEENUM.mongo,
        schema:{
            id:{ type:'String', index:true },
            agencyId:{type:'String', index:true},//机构id
            name:'String',
            type:'Number',
            fileUrl:'String',
            ct:'Number',//创建时间
        }
    },
    {
        tableName:TABLEENUM.用户表,
        source:TABLESOURCEENUM.mongo,
        schema:{
            userId:{ type:'String', index:true },//唯一标识
            isAdmin:{ type:'Number', default:0},//是否是管理员
            memberType:{type:'Number'},//会员类型 MEMBERTYPE
            unitMemberType:{type: 'Number'},//单位会员类型
            individualMemberType:{type: 'Number'},//个人会员类型
            name:{type:'String'},//真实姓名
            loginId:{ type:'String', index:true},//用户名
            pwd:{ type:'String'},//密码
            token:{type:'String', default:''},//token
            tokenMs:{type:'Number', default:0},//token过期时间
            phone:{type:'String', index:true},//联系电话  登陆手机号
            mail:{type:'String', index:true},//邮箱
            sex:'Number',//性别 枚举
            documentType:'Number',//证件类型 枚举
            documentId:'String',//证件id 身份证
            birth:'Number',//出生年月 时间戳
            nation:'Number',//民族 枚举
            sheng:'String',//省
            shi:'String',//市
            qu:'String',//区
            addres:'String',//通信地址
            photoUrl:'String',//证件照图片地址 蓝底证件照
            workUnit:'String',//工作单位
            workDuties:'String',//职务
            workTitle:'String',//职称
            userRegisterState:{type:'Number', default:USERREGISTERSTATE.待审核, index:true},//用户注册状态 枚举
            registerFlow:'Number',//会员注册流程 枚举
            auditTime:'Number',//审核时间
            memberState:{type:'Number', default:MEMBERSTATE.正常, index:true},//会员状态 枚举
            askForTime:'Number',//申请时间
            joinTime:'Number',//入会时间
            session:'String',//届次
            memberLevel:'Number',//会员等级 枚举
            lifespanStartTime:'Number',//会员有效期开始时间 时间戳
            lifespanEndTime:'Number',//会员有效期结束时间 时间戳
            isGracePeriod:{type:'Number', default:0},//是否宽限期 0：否， 1：是
            gracePeriodEndTime:'Number',//宽限期到期时间 时间戳
            certificateType:'Number',//证书类型 枚举

            unitName:'String',//单位名称
            officialWebsite:'String',//官网 单位网址
            uscc:'String',//统一信用代码
            legalPerson:'String',//法人
            legalPersonPhone:'String',//法人代表联系电话
            gongZhongHao:'String',//单位公众号
            unitPhone:'Number',//单位电话
            contactPerson:'String',//日常联系人
            contactPersonDuties:'String',//日常联系人职务
            uusinessLicenseUrl:'String',//营业执照 图片地址
            personInChargeDesc:'String',//单位主要负责人或负责人集体描述

            /**单位会员信息 */
            unitInfoType:'Number',//单位信息类型 枚举
            yuanXiaoBanXueLeiXing:'String',//院校办学类型
            yuanXiaoZhuGuanBuMen:'String',//院校主管部门
            yuanXiaoFuZeRen:'String',//院校主要负责人
            yuanXiaoFuZeRenZhiWu:'String',//院校主要负责人职务
            yuanXiaoFuZeRenDianHua:'String',//院校主要负责人电话
            yuanXiaoBanGongFuZeRen:'String',//院校办公负责人
            yuanXiaoBanGongFuZeRenZhiWu:'String',//院校办公负责人职务
            yuanXiaoBanGongFuZeRenDianHua:'String',//院校办公负责人电话
            yuanXiaoKeYanFuZeRen:'String',//院校办公负责人
            yuanXiaoKeYanFuZeRenZhiWu:'String',//院校办公负责人职务
            yuanXiaoKeYanFuZeRenDianHua:'String',//院校办公负责人电话
            yuanXiaoXueShengZongRenShu:'String',//学生总人数
            yuanXiaoJiaoZhiGongZongRenShu:'String',//教职工总人数
            yuanXiaoJianZhuMianJi:'String',//院校建筑面积
            yuanXiaoGaoJiZhiCheng:'String',// 院校职称
            yuanXiaoKaiSheZhuanYe:'String',//院校开设专业数
            
            /**个人会员信息 */
            cardUrl:{type:'[String]', default:[]},//身份证正反面图片地址
            academicCERTUrl:'String',//学历证明图片地址
            professionalCERTUrl:'String',//工作证明图片地址
            auxiliaryMaterial:{type:'[String]', default:[]},//其他辅助材料
            profCategory:'Number',//专业类别 枚举
            studyResume:'String',//学习简历
            workResume:'String',//工作简历
            profAchievement:'String',//专业成果
            otherEMP:'String',//其他任职情况
            otherPROF:'String',//其他专业情况

        }
    },
    {
        tableName:TABLEENUM.单位所获得科研成果表,
        source:TABLESOURCEENUM.mongo,
        schema:{
            id:{ type:'String', index:true },
            userId:'String',//用户id 外键
            startTime:'Number',//开始时间
            endTime:'Number',//结束时间
            describe:'String',//描述
        }
    },
    {
        tableName:TABLEENUM.订单表,
        source:TABLESOURCEENUM.mongo,
        schema:{
            id:{ type:'String', index:true },
            orderYear:'String',//订单年度
            unitName:'String',//单位名称
            orderCycleStart:'Number',//订单周期开始时间
            orderCycleEnd:'Number',//订单周期结束时间
            money:'String',//金额 
            memberId:'String',//会员id
            loginId:'String',//登陆名
            phone:"String",//登陆手机号
            paymentNum:'String',//支付单号（与订单号不一样）
            // membershipFeesType:'Number',//会费类别 枚举
            invoiceAdd:'String',//发票图片地址
            state:'Number',//状态 枚举 ORDERSTATE
            isFirst:{type:'Boolean', default:true},//首次订单
            invoiceStatus:{type:'Number', index:true},//发票状态 枚举 INVOICESTATUS
            paymentMethod:'Number',//付款方式 枚举  PAYMENTTYPE
            memberCategory:'Number',//会员类别 枚举  MEMBERTYPE
        }
    },
    {
        tableName:TABLEENUM.验证码表,
        source:TABLESOURCEENUM.mongo,
        schema:{
            codeId:{type:'String', index:true},
            codeNum:'String',
            sendMs:'Number',//下发时间 时间戳
            phone:{type:'String', index:true},//用户电话
            type:'Number',//验证码类型 
            isUse:{type:'Boolean', default:false},//是否使用 默认false
        }
    },
];



export {ModelArray, TABLEENUM, TABLESOURCEENUM};

